@@ -7,7 +7,6 @@ import datetime
 import copy
 from multiprocessing import Lock
 import traceback
-import configparser
 import jpype
 import socket
 from .testcliexception import TestCliException
@@ -32,10 +31,14 @@ class TestCliMeta(object):
         self.MetaURL = None
         self.MetaPort = 0
         self.JarList = None
+        self.appOptions = None
 
     def setJVMJarList(self, p_JarList):
         self.JarList = p_JarList
 
+    def setAppOptions(self, appOptions):
+        self.appOptions = appOptions
+
     def DisConnect(self):
         if self.dbConn is not None:
             self.dbConn.close()
@@ -56,20 +59,10 @@ class TestCliMeta(object):
             self.MetaServer = None
 
     def StartAsServer(self):
-        # 检查TESTCLI_HOME是否存在
         try:
             # 读取配置文件，并连接数据库
-            m_AppOptions = configparser.ConfigParser()
-            m_conf_filename = os.path.join(os.path.dirname(__file__), "conf", "testcli.ini")
-            m_AppOptions.read(m_conf_filename)
-            m_MetaClass = m_AppOptions.get("meta_driver", "driver")
-            m_MetaDriverFile = os.path.join(os.path.dirname(__file__),
-                                            "jlib", m_AppOptions.get("meta_driver", "filename"))
-            if not os.path.exists(m_MetaDriverFile):
-                raise TestCliException("TestCli-0000: "
-                                       "TestCliMeta:: Driver file [" + m_MetaDriverFile +
-                                       "] does not exist! JobManager Aborted!")
-            m_MetaDriverURL = m_AppOptions.get("meta_driver", "jdbcurl")
+            m_MetaClass = self.appOptions.get("meta_driver", "driver")
+            m_MetaDriverURL = self.appOptions.get("meta_driver", "jdbcurl")
             self.dbConn = jdbcconnect(jclassname=m_MetaClass, url=m_MetaDriverURL,
                                       driverArgs={'user': 'sa', 'password': 'sa'},
                                       jars=self.JarList)
@@ -223,22 +216,8 @@ class TestCliMeta(object):
 
         try:
             # 读取配置文件，并连接数据库
-            m_AppOptions = configparser.ConfigParser()
-            m_conf_filename = os.path.join(os.path.dirname(__file__), "conf", "testcli.ini")
-            if os.path.exists(m_conf_filename):
-                m_AppOptions.read(m_conf_filename)
-            else:
-                if "TESTCLI_DEBUG" in os.environ:
-                    print("DEBUG:: TestCliMeta:: testcli.ini does not exist! JobManager Connect Failed!")
-                return
-            m_MetaClass = m_AppOptions.get("meta_driver", "driver")
-            m_MetaDriverFile = os.path.join(os.path.dirname(__file__),
-                                            "jlib", m_AppOptions.get("meta_driver", "filename"))
-            if not os.path.exists(m_MetaDriverFile):
-                if "TESTCLI_DEBUG" in os.environ:
-                    print("DEBUG:: TestCliMeta:: Driver file does not exist! JobManager Connect Failed!")
-                return
-            m_MetaDriverURL = m_AppOptions.get("meta_driver", "jdbcurl")
+            m_MetaClass = self.appOptions.get("meta_driver", "driver")
+            m_MetaDriverURL = self.appOptions.get("meta_driver", "jdbcurl")
             m_MetaDriverURL = m_MetaDriverURL.replace("mem", p_MetaServerURL + "/mem")
             self.dbConn = jdbcconnect(jclassname=m_MetaClass, url=m_MetaDriverURL,
                                       driverArgs={'user': 'sa', 'password': 'sa'},
@@ -1193,7 +1172,7 @@ class JOBManager(object):
         except Exception:
             print("Internal error:: Save Job write not complete. ")
             import traceback
-            if "TESTCLI_DEBUG" in os.environ:
+            if "TESTCLI_DEBUG" not in os.environ:
                 print('traceback.print_exc():\n%s' % traceback.print_exc())
                 print('traceback.format_exc():\n%s' % traceback.format_exc())
         finally:
@@ -1626,6 +1605,12 @@ class JOBManager(object):
                     "message": "Job manager already started. You can not start job manager again."
                 }
         if requestObject["action"] == "stopJobmanager":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started.",
+                }
+                return
             if cls.testOptions.get("JOBMANAGER").upper() == "ON":
                 del os.environ["TESTCLI_JOBMANAGERURL"]
                 cls.testOptions.set("JOBMANAGER", "OFF")
@@ -1645,9 +1630,21 @@ class JOBManager(object):
                     "message": "Job manager already stopped. You can not stop job manager again."
                 }
         if requestObject["action"] == "show":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             jobName = requestObject["jobName"]
             yield self.showjob(jobName)
         if requestObject["action"] == "create":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             jobName = requestObject["jobName"]
             params = dict(requestObject["param"])
             job = self.createjob(jobName)
@@ -1663,6 +1660,12 @@ class JOBManager(object):
                 "status": "Job [" + jobName + "] created successful."
             }
         if requestObject["action"] == "set":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             jobName = requestObject["jobName"]
             params = dict(requestObject["param"])
             job = self.getJobByName(jobName)
@@ -1678,6 +1681,12 @@ class JOBManager(object):
                 "status": "Job [" + jobName + "] set successful."
             }
         if requestObject["action"] == "start":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             jobName = requestObject["jobName"]
             nJobStarted = self.startjob(jobName)
             yield {
@@ -1689,6 +1698,12 @@ class JOBManager(object):
                 "status": "Total [" + str(nJobStarted) + "] jobs started."
             }
         if requestObject["action"] == "wait":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             jobName = str(requestObject["jobName"])
             self.waitjob(jobName)
             if jobName.strip().upper() == "ALL":
@@ -1710,6 +1725,12 @@ class JOBManager(object):
                     "status": "Job [" + jobName + "] finished."
                 }
         if requestObject["action"] == "shutdown":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             jobName = requestObject["jobName"]
             nJobShutdowned = self.shutdownjob(jobName)
             yield {
@@ -1721,6 +1742,12 @@ class JOBManager(object):
                 "status": "Total [" + str(nJobShutdowned) + "] jobs shutdown complete."
             }
         if requestObject["action"] == "abort":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             jobName = requestObject["jobName"]
             nJobAbortted = self.abortjob(jobName)
             yield {
@@ -1732,6 +1759,12 @@ class JOBManager(object):
                 "status": "Total [" + str(nJobAbortted) + "] jobs abort complete."
             }
         if requestObject["action"] == "timer":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             timerPoint = requestObject["timerPoint"]
             self.waitjobtimer(timerPoint)
             yield {
@@ -1743,6 +1776,12 @@ class JOBManager(object):
                 "status": "TimerPoint [" + timerPoint + "] has arrived."
             }
         if requestObject["action"] == "register":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             jobName = requestObject["jobName"]
             self.registerjob(jobName)
             yield {
@@ -1754,6 +1793,12 @@ class JOBManager(object):
                 "status": "Register worker to Job [" + str(jobName) + "] successful."
             }
         if requestObject["action"] == "deregister":
+            if self.MetaConn is None:
+                yield {
+                    "type": "error",
+                    "message": "JOB Manager is not started. Please use \"_JOB JOGMANAGER ON\" first.",
+                }
+                return
             self.unregisterjob()
             yield {
                 "type": "result",
